import QtQuick 2.14
import QtQuick.Layouts 1.12
import QtMultimedia 5.14

Rectangle {
	id: root

	// ASSIGN TO FOLDER PATH WITH PREVIEWS ON YOU FILESYSTEM
	readonly property string previewsDirectoryPath: "/Users/andy/tasks/VideoPlayerBugTestPreviews"

	width: 640
	height: 480
	color: "#1A1D21"

	Flickable {
		y: parent.height / 2 - contentItem.childrenRect.height / 2
		x: parent.width / 2 - contentItem.childrenRect.width / 2
		width: contentItem.childrenRect.width
		height: 162
		flickableDirection: Flickable.HorizontalFlick

		RowLayout {
			anchors {
				left: parent.left
				top: parent.top
				bottom: parent.bottom
			}

			Repeater {
				model: 3

				delegate: flickableDelegate
			}
		}
	}

	MediaPlayer {
		id: sharedMediaPlayer
		autoPlay: false
		autoLoad: true
		loops: MediaPlayer.Infinite
	}
	VideoOutput {
		id: sharedVideoPlayer
		source: sharedMediaPlayer
	}

	Component {
		id: flickableDelegate
		Image {
			id: placeHolder

			readonly property url previewImagrPlaceholderUrl: "file:///" + previewsDirectoryPath + "/" + index + "/preview_placeholder.jpg"
			readonly property url previewVideoUrl: "file:///" + previewsDirectoryPath + "/" + index + "/preview.avi"
			Layout.preferredWidth: 90
			Layout.preferredHeight: 162

			source: previewImagrPlaceholderUrl

			MouseArea {
				id: ma
				anchors.fill: parent
				hoverEnabled: true

				Timer {
					id: timer

					interval: 150

					onTriggered: privatePart.previewing = ma.containsMouse;
				}

				onHoveredChanged: {
					if(containsMouse)
					{
						timer.start();
					}
					else
					{
						privatePart.previewing = false;
					}
				}
			}

			QtObject {
				id: privatePart

				property bool previewing: false
				property bool dontPlay: false

				function showVideoPreview()
				{
					sharedMediaPlayer.source = previewVideoUrl;

					placeHolder.mipmap = true;
					sharedVideoPlayer.parent = placeHolder;
					sharedVideoPlayer.anchors.fill = placeHolder;
					sharedVideoPlayer.visible = true;
					sharedMediaPlayer.play()
				}

				function hideVideoPreview()
				{
					placeHolder.mipmap = false;
					sharedMediaPlayer.source = "";
					sharedVideoPlayer.visible = false;
					sharedVideoPlayer.parent = root;
					sharedVideoPlayer.anchors.fill = undefined;
					sharedMediaPlayer.stop();
				}
				onPreviewingChanged: {
					if(previewing)
					{
						showVideoPreview();
					}
					else
					{
						hideVideoPreview();
					}
				}
			}
		}
	}
}
